say_status :CAPISTRANO, 'Capifying application...', :yellow

deploy_header = <<-END
# ——————————————
# Setting up RVM
# ——————————————
$:.unshift(File.expand_path('./lib', ENV['rvm_path']))
require 'rvm/capistrano'
require 'bundler/capistrano'

# ––––––––––––––––––
# APPLICATION SERVER
# ————————————————––
set :application, "~app_name~"
set :user,        "~user~"
set :domain,      "~domain~"
set :port,        ~port~
set :deploy_to,   '/apps/~app_name~'

# ––––––––––––––
# DEPLOY OPTIONS
# —————————————–
role :app, domain
role :web, domain
role :db,  domain, :primary => true
set :scm,           :git
set :use_sudo,      false
set :keep_releases, 3
set :default_run_options, { :pty => true }
set :ssh_options, {
  :forward_agent => true,
  :paranoid => false,
  :keys => ["~keys~"],
  :port => port
}

END

deploy_github = <<-END
# ––––––––––––––––––
# REPOSITORY: GITHUB
# ––––––––––––––––––
set :repository,  "git://github.com/~github_account~/~app_name~.git"

END

deploy_fs = <<-END
# ––––––––––––––
# REPOSITORY: FS
# ––––––––––––––
set :repository,       "file:///home/git/repositories/~app_name~"
set :local_repository, "fs.git:/home/git/repositories/~app_name~"
set :deploy_via,       :remote_cache

END

deploy_footer = <<-END
# ———————————–––––—
# FUNKENPLATE HOOKS
# ————————————–––––
after  'deploy:setup',       'deploy:setup_additions'
after  'deploy:update_code', 'deploy:additional_symlinks'

# ———————————–
# DEPLOY TASKS
# ————————————
namespace :deploy do
  
  # Happens after initial setup
  desc "Add some more dirs into shared"
  task :setup_additions do
    mkshared 'private'
    mkshared 'config'
    run "touch \#{shared_database}"
    logger.important "REMEMBER TO EDIT \#{shared_database} ON THE SERVER - NOT in THIS shell!" unless test_remote? :file_with_content, repository_on_server?
  end
  
  # Happens with each release
  desc "Link in critical data from shared and install bundles"
  task :additional_symlinks do
    symlinker 'config/database.yml'
    symlinker 'private'
  end
  
  # Overwriting default spin scripts
  desc 'Restart passenger'
  task :restart, :roles => :app, :except => { :no_release => true } do
    run "touch \#{File.join(current_path,'tmp','restart.txt')}"
  end
  task :start do; end
  task :stop  do; end
  
end

# ———————————–––
# HELPER METHODS
# ————————————––

# Creates a symlink from <tt>deploy_to/shared/...</tt> to <tt>release_path/...</tt>
# If <tt>to</tt> is omitted, the release path mirrors in the shared path
def symlinker(from, to='')
  to = from if to.blank?
  run "ln -nfs \#{File.join deploy_to, 'shared', from} \#{File.join release_path, to}"
end

END


say_status :CAPISTRANO, 'Capify...', :magenta
capify!

say_status :CAPISTRANO, 'Backup original deploy.rb...', :magenta
run 'cp config/deploy.rb config/deploy.rb.sample'

say_status :CAPISTRANO, 'Generating deploy.fs.rb for repositories on fs server...', :magenta
file 'config/deploy.fs.rb', deploy_header.personalize(app_name, @secrets) + deploy_fs.personalize(app_name, @secrets) + deploy_footer

say_status :CAPISTRANO, 'Generating deploy.github.rb for repositories on github.com...', :magenta
file 'config/deploy.github.rb', deploy_header.personalize(app_name, @secrets) + deploy_github.personalize(app_name, @secrets) + deploy_footer

say_status :GIT, 'Commiting capistrano changes...', :magenta
git :add => '.'
git :commit => "-a -m 'Capified the app.'"