require 'yaml'
require File.join(File.dirname(__FILE__), '..', 'string')

# This is where we will search for funkenplate.yml containing individual secrets
secret_files = []
directories  = ['..', ENV['HOME'], File.join(ENV['HOME'], '.ssh')]
files        = ['funkenplate.yml', '.funkenplate.yml']
directories.each { |directory| files.each { |file| secret_files << File.expand_path(File.join(directory, file)) } }

# –––––––––––––––
# DEFAULT SECRETS
# –––––––––––––––

# Default secrets
default_secrets = {
  :version => Gem.source_index.find_name('funkenplate').last.version.version,
  :deploy => {
    :app_server => {
      :user   => ENV['USER'].downcase,
      :domain => 'YOUR_SERVER_DOMAIN_OR_IP_GOES_HERE',
      :port   => 22,
      :keys => File.expand_path(File.join(ENV['HOME'], '.ssh', 'YOUR_PRIVATE_KEY'))
    },
    :github => {
      :account => 'YOUR_GITHUB_ACCOUNT_NAME_GOES_HERE'
    }
  }
}

# –––––––––––––––––
# OBTAINING SECRETS
# –––––––––––––––––

@secrets = default_secrets

if secret_file = secret_files.find { |file| File.file? file }
  @secrets = YAML.load_file secret_file
else
  shout_status :error, "I could not find funkenplate.yml anywhere but I created one for you. You must edit it and then re-apply this template.", :red
  say_status :info, "Note that you can put that yml file into any of these locations (top ones with higher priority):", :yellow
  secret_files.each { |location| say_status '', "  #{location}" }
  shout_status :create, secret_files.first
  File.open(secret_files.first, 'w') { |file| file.write YAML::dump(default_secrets) }
  exit 3
end

shout_status :ENVIRONMENT, "These is the stuff we're working with here:", :yellow
print_table [
  ['Application name:', app_name],
  ['Application location:', destination_root],
  ['Funkenplate gem:', Gem.source_index.find_name('funkenplate').last.full_gem_path],
  ['Secret file:', secret_file],
], :ident => 18

shout_status :SECRETS, "I was able to obtain these secrets from the secret file:", :yellow
print_table [
  ['Application Server domain:', @secrets[:deploy][:app_server][:domain]],
  ['Application Server SSH user:', @secrets[:deploy][:app_server][:user]],
  ['Application Server SSH port:', @secrets[:deploy][:app_server][:port]],
  ['Github account:', @secrets[:deploy][:github][:account]],
  ['Location of your SSH key:', @secrets[:deploy][:app_server][:keys]],
], :ident => 18

unless yes?("Are these values correct?")
  shout_status :EXITING, "OK, please edit this file first: #{secret_file}"
  exit 1
end